@@ -10,9 +10,9 @@ Useful functions for terminal-based programs.
 #  Parts of the docstrings based on the Python 3.8.2 Documentation
 #  Licensed under the Python Software Foundation License Version 2.
 #  Copyright © 2001-2020 Python Software Foundation. All rights reserved.
-#  Copyright © 2000 BeOpen.com . All rights reserved.
-#  Copyright © 1995-2000 Corporation for National Research Initiatives . All rights reserved.
-#  Copyright © 1991-1995 Stichting Mathematisch Centrum . All rights reserved.
+#  Copyright © 2000 BeOpen.com. All rights reserved.
+#  Copyright © 1995-2000 Corporation for National Research Initiatives. All rights reserved.
+#  Copyright © 1991-1995 Stichting Mathematisch Centrum. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU Lesser General Public License as published by
@@ -88,7 +88,7 @@ def clear() -> None:
 	if os.name == "nt":  # pragma: no cover (!Windows)
 		os.system("cls")  # nosec: B607,B605
 	else:  # pragma: no cover (!Linux)
-		print("\033c", end='')
+		print("\u001bc", end='')
 
 
 def br() -> None:
@@ -170,7 +170,7 @@ class Echo:
 	:param indent: The indentation of the dictionary of variable assignments.
 	"""
 
-	def __init__(self, indent: str = " " * 2):
+	def __init__(self, indent: str = ' ' * 2):
 		self.indent = indent
 
 		frame = inspect.currentframe()
