@@ -84,7 +84,7 @@ import typing
 import warnings
 from datetime import date
 from pprint import pformat
-from typing import Any, Callable, Dict, Iterable, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 # 3rd party
 import deprecation  # type: ignore
@@ -278,7 +278,7 @@ def posargs2kwargs(
 	return kwargs
 
 
-def convert_indents(text: str, tab_width: int = 4, from_: str = "\t", to: str = " ") -> str:
+def convert_indents(text: str, tab_width: int = 4, from_: str = '\t', to: str = ' ') -> str:
 	r"""
 	Convert indentation at the start of lines in ``text`` from tabs to spaces.
 
@@ -301,7 +301,7 @@ def convert_indents(text: str, tab_width: int = 4, from_: str = "\t", to: str =
 
 		output.append(f"{tab * indent_count}{line}")
 
-	return "\n".join(output)
+	return '\n'.join(output)
 
 
 class _Etcetera(str):
@@ -453,7 +453,7 @@ def deprecated(
 		existing_docstring = function.__doc__ or ''
 
 		# split docstring at first occurrence of newline
-		string_list = existing_docstring.split("\n", 1)
+		string_list = existing_docstring.split('\n', 1)
 
 		if should_warn:
 			# The various parts of this decorator being optional makes for
@@ -461,19 +461,21 @@ def deprecated(
 			# makes for a nicely constructed sentence with or without any
 			# of the parts.
 
-			# If removed_in is a date, use "removed on"
-			# If removed_in is a version, use "removed in"
-			parts = {
-					"deprecated_in":
-							f" {deprecated_in}" if deprecated_in else '',
-					"removed_in":
-							f"\n   This will be removed {'on' if isinstance(removed_in, date) else 'in'} {removed_in}."
-							if removed_in else '',
-					"details":
-							f" {details}" if details else ''
-					}
+			parts = {"deprecated_in": '', "removed_in": '', "details": ''}
 
-			deprecation_note = (".. deprecated::{deprecated_in}{removed_in}{details}".format(**parts))
+			if deprecated_in:
+				parts["deprecated_in"] = f" {deprecated_in}"
+			if removed_in:
+				# If removed_in is a date, use "removed on"
+				# If removed_in is a version, use "removed in"
+				if isinstance(removed_in, date):
+					parts["removed_in"] = f"\n   This will be removed on {removed_in}."
+				else:
+					parts["removed_in"] = f"\n   This will be removed in {removed_in}."
+			if details:
+				parts["details"] = f" {details}"
+
+			deprecation_note = (".. deprecated::{deprecated_in}{removed_in}{details}".format_map(parts))
 
 			# default location for insertion of deprecation note
 			loc = 1
@@ -495,7 +497,7 @@ def deprecated(
 				string_list[1] = textwrap.dedent(string_list[1])
 
 				# we need another newline
-				string_list.insert(loc, "\n")
+				string_list.insert(loc, '\n')
 
 				# change the message_location if we add to end of docstring
 				# do this always if not "top"
@@ -613,14 +615,14 @@ def check_dependencies(dependencies: Iterable[str], prt: bool = True) -> List[st
 		details="Import from :mod:`consolekit.utils` (v0.3.0 or later) instead.",
 		)
 def coloured_diff(
-		a: Sequence[str],
-		b: Sequence[str],
+		a: typing.Sequence[str],
+		b: typing.Sequence[str],
 		fromfile: str = '',
 		tofile: str = '',
 		fromfiledate: str = '',
 		tofiledate: str = '',
 		n: int = 3,
-		lineterm: str = "\n",
+		lineterm: str = '\n',
 		removed_colour: Colour = Fore.RED,
 		added_colour: Colour = Fore.GREEN,
 		) -> str:
